import { fullUserAvatarFragment } from '../users/queries.js'

const postImageFragment = `
  fragment PostImageData on PostImage {
    id
    url
    height
    width
  }
`

const linkFragment = `
  fragment LinkFragment on LinkPreview {
    requestedUrl
    url
    title
    description
    type
    image
    siteName
    origin
  }
`

export const spaceUpdatePostFragment = `
  ${fullUserAvatarFragment}
  ${postImageFragment}
  ${linkFragment}

  fragment SpaceUpdatePostFragment on Post {
    id
    title
    text
    created
    creator {
      ...FullUserAvatar
    }
    numberOfComments
    commenters {
      totalResults
      data {
        ...FullUserAvatar
      }
    }
    image {
      ...PostImageData
    }
    links {
      ...LinkFragment
    }
    mentions {
      id
      fullName
    }
    myReaction {
      HEART
    }
    reactions {
      HEART
    }
    isPublic
  }
`

export const postCommentDetailFragment = `
  fragment PostCommentDetail on PostComment {
    id
    text
    created
    creator {
      id
      identity
      avatar
      avatarBlurhash
      avatarLabel
      avatarDefaultColor
      fullName
      aboutMe
      pronouns
    }
    mentions {
      id
      fullName
    }
    myReaction {
      HEART
    }
    reactions {
      HEART
    }
  }
`

export const postCommentFragment = `
  fragment PostCommentFull on PostComment {
    id
    text
    created
    creator {
      id
      identity
      avatar
      avatarBlurhash
      avatarLabel
      avatarDefaultColor
      fullName
      aboutMe
      pronouns
    }
    mentions {
      id
      fullName
    }
    myReaction {
      HEART
    }
    reactions {
      HEART
    }
  }
`

export const postDetailsFragment = `
  ${fullUserAvatarFragment}
  ${postCommentFragment}
  ${postImageFragment}
  ${linkFragment}

  fragment PostFull on Post {
    id
    title
    text
    created
    creator {
      ...FullUserAvatar
    }
    numberOfComments
    commenters {
      totalResults
      data {
        ...FullUserAvatar
      }
    }
    comments {
      ...PostCommentFull
    }
    image {
      ...PostImageData
    }
    links {
      ...LinkFragment
    }
    mentions {
      id
      fullName
    }
    myReaction {
      HEART
    }
    reactions {
      HEART
    }
    isPublic
  }
`

export const postFragment = `
  ${fullUserAvatarFragment}
  ${postImageFragment}
  ${linkFragment}

  fragment PostFragment on Post {
    id
    title
    text
    created
    creator {
      ...FullUserAvatar
    }
    numberOfComments
    commenters {
      totalResults
      data {
        ...FullUserAvatar
      }
    }
    image {
      ...PostImageData
    }
    links {
      ...LinkFragment
    }
    mentions {
      id
      fullName
    }
    myReaction {
      HEART
    }
    reactions {
      HEART
    }
  }
`

export const postByIdQuery = `
${postFragment}

query PostById($postId: UUID!) {
  postById(id: $postId) {
    ...PostFragment
  }
}
`

export const inspirationPostsQuery = `
  ${postFragment}
  query InspirationPosts($offset: Int = 0, $limit: Int = 10) {
    inspirationPosts(offset: $offset, limit: $limit) {
      data {
        ...PostFragment
      }
      totalResults
    }
  }
`
